DefaultOnboardingLayout class final

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

DefaultOnboardingLayout()
DefaultOnboardingLayout.fromJson(Map<String, dynamic> json)
factory

Properties

contentType → Type
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
The schema type of the content item.
finalinherited

Methods

build(BuildContext context, OnboardingContent content) → Widget
Builds the layout widget tree for the given content item.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

typeDescriptor → TypeDescriptor<DefaultOnboardingLayout>
final

Constants

schemaName → const String