OnboardingContentBuilder class
final
Methods
-
addDescriptors(List<ContentDescriptor> descriptors)
→ void
-
Additively registers new descriptors into this builder.
inherited
-
build(BuildContext context, OnboardingContent content)
→ Widget
-
Builds a widget for the given content item.
inherited
-
init(List<ContentDescriptor> descriptors)
→ void
-
Initializes this content builder with the given descriptors.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
registerDescriptors<U>(Iterable<TypeDescriptor<U>> descriptors, {bool checkUnique = false})
→ void
-
Registers a list of type descriptors with the content system.
inherited
-
setDefaultLayout(LayoutConfiguration<OnboardingContent> layout, {required FromJsonConverter<LayoutConfiguration<OnboardingContent>> fromJson, String? sourceFeatureName})
→ void
-
Sets the default layout for this content builder.
inherited
-
setSourceFeature(String? featureName)
→ void
-
Updates the source feature for this builder and its layouts.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited