OnboardingDescriptor class final

Inheritance
  • Object
  • ContentDescriptor
  • OnboardingDescriptor

Constructors

OnboardingDescriptor({List<TypeDescriptor<LayoutConfiguration<ContentItem>>>? layouts})

Properties

hashCode → int
The hash code for this object.
no setterinherited
layouts → List<TypeDescriptor<LayoutConfiguration<ContentItem>>>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
finalinherited
sourceFeature → String?
The feature that this content descriptor was registered by.
no setterinherited
title → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSourceFeature(String? featureName) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited